# Change log

## [v0.2.0](https://github.com/cofiem/screenshot-ocr/releases/tag/v0.2.0)

Release 2025-07-05

- Add cli commands to list config and playlist tracks
- Introduce release publish via PyPI Trusted Publishing.
- Add GitHub Actions for checking coverage, Actions security, test coverage, linters.
- Lots of minor code updates to satisfy linters.
- Migrate to hatch
